fetch_code_via_rpc

Function fetch_code_via_rpc 

pub(crate) async fn fetch_code_via_rpc<N: Network, P: Provider<N>>(
    provider: &P,
    addresses: impl IntoIterator<Item = Address>,
    block: BlockId,
) -> AddressHashMap<Bytes>
Fetches the non-empty code of addresses at block with bounded concurrency, warning about addresses whose code cannot be fetched.