pub(crate) fn rpc_provider(rpc: &RpcOpts) -> Result<RetryProvider>Expand description
Loads the config for rpc and builds the default provider from it.
pub(crate) fn rpc_provider(rpc: &RpcOpts) -> Result<RetryProvider>Loads the config for rpc and builds the default provider from it.